@@ -22,7 +22,7 @@ module Mopt
       @opts[:error_level] = v.is_a?(Integer) ? v : 3 }
     opt.on('--profile', 'Profiling mode (for development)') { @opts[:profile] = true }
     opt.on('--skip-version-check', 'Skip library and environment version check') { @opts[:skip_version_check] = true }
-    opt.on('-p', '--plugin=', 'Plugin slug to load (comma separated)'){ |plugins| @opts[:plugin] = (@opts[:plugin]||[]).concat plugins.split(",") }
+    opt.on('-p', '--plugin=', 'Load specified plugins and depended plugins (comma separated)'){ |plugins| @opts[:plugin] = (@opts[:plugin]||[]).concat plugins.split(",") }
     opt.on('--confroot=', 'set confroot directory') { |v|
       @opts[:confroot] = File.expand_path(v) }
     opt.on('--daemon', '-d'){
